@@ -1,5 +1,5 @@
 package Test::Git;
-$Test::Git::VERSION = '1.311';
+$Test::Git::VERSION = '1.312';
 use strict;
 use warnings;
 
@@ -33,7 +33,7 @@ sub has_git {
 sub test_repository {
     my %args = @_;
 
-    croak "Can't use both 'init' and 'clone' paramaters"
+    croak "Can't use both 'init' and 'clone' parameters"
         if exists $args{init} && exists $args{clone};
 
     # setup some default values
@@ -45,7 +45,7 @@ sub test_repository {
 
     # version check
     my ( $cmd, $min_version ) = $clone ? ( clone => '1.6.2.rc0' )
-                                       : ( init  => '1.5.0.rc1' );
+                                       : ( init  => '1.4.0' );
     my $git_version = Git::Repository->version($safe);
     croak "test_repository( $cmd => ... ) requires git >= $min_version (this is only $git_version)"
       if Git::Repository->version_lt( $min_version, $safe );
@@ -55,7 +55,9 @@ sub test_repository {
     my $cwd = { cwd => $dir };    # option to chdir there
 
     # create the git repository there
-    my @cmd = $clone ? ( clone => @$clone, $dir ) : ( init => @$init, $cwd );
+    unshift @$init,
+        Git::Repository->version_lt('1.5.0.rc1') ? 'init-db' : 'init';
+    my @cmd = $clone ? ( clone => @$clone, $dir ) : ( @$init, $cwd );
     Git::Repository->run( @cmd, $safe );
 
     # create the Git::Repository object
@@ -77,7 +79,7 @@ Test::Git - Helper functions for test scripts using Git
 
 =head1 VERSION
 
-version 1.311
+version 1.312
 
 =head1 SYNOPSIS
 
